| CollisionIntegral-class | R Documentation |
"CollisionIntegral"Class for the empirical interpolation functions for 16 reduced Lennard-Jones (12-6) collision integrals
in the range 0.3 <= \RTheta <= 400.
\RemphCollision integrals as function of reduced temperature \RTheta
l:order of collision integral l
s:order of collision integral s
coeff:coefficients for collision integrals for order l and s, see data set coefficients_collisionintegral
A:model parameter \RemphA
B:model parameter \RemphB\sub1 ... B\sub6
C:model parameter \RemphC\sub1 ... C\sub6
initialize(s, l):Initialize reduced collision integral of order l and s
Omega(Theta):Calculates reduced collision integral \ROmega(l,s) at reduced temperature \Theta using the empirical interpolation function
Kim SU, Monroe CW. High-accuracy calculations of sixteen collision integrals for Lennard-Jones (12-6) gases and their interpolation to parameterize neon, argon, and krypton. \RemphJournal of Computational Physics 2014;273:35873. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jcp.2014.05.018")}.
O11 <- CollisionIntegral(l=1,s=1)
O11$Omega(0.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.