ethane_data: Viscosity and second virial coefficient of ethane

ethane_dataR Documentation

Viscosity and second virial coefficient of ethane

Description

Reference values for the second virial coefficient and viscosity of ethane from a intermolecular potential energy surface. The second virial coefficient was calculated semiclassically by means of the Mayer-sampling Monte Carlo technique, while the transport properties were obtained using the classical kinetic theory of polyatomic gases. The computed thermophysical property values are in excellent agreement with the best available experimental data and are recommended as reference values.

Usage

data("ethane_data")

Format

A data frame with 107 observations on the following 4 variables.

T

Temperature in K

property

Type of property. B: classically calculated second virial coefficient, BQFH: second virial coefficient calculated by a modification of the pair potential known as the quadratic Feynman-Hibbs (QFH) effective pair potential. viscosity: gas phase viscosity

unit

a factor with levels cm3/mol, uPa.s

value

numerical value of property. For the second virial coefficient the calculated data are supported by experimental data in the temperature range 220 - 623 K. For the viscosity the calculated data are supported by experimental data in the temperature range 90 - 675 K.

Details


\Remph(a) Viscosity of ethane. (b) second virial coefficient of ethane. The black solid curves are fits using viscosity data and second virial coefficient data respectively. The red dotted curves are simultaneous fits against the viscosity and second virial coefficient data.

Type of fit \Rsigma \Rvarepsilon/k
vs. viscosity data 4.38(2) 235(6)
vs. second virial coefficient data 4.95(6) 202(3)
vs. viscosity and second virial coefficient data 4.35 244

Hellmann R. Reference Values for the Second Virial Coefficient and Three Dilute Gas Transport Properties of Ethane from a State-of-the-Art Intermolecular Potential Energy Surface. \RemphJournal of Chemical & Engineering Data 2018;63:470-81. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1021/acs.jced.7b01069")}.

Examples

## Not run: 	
c2h6 <- Gas("ethane")
# estimate LJ-coefficients from viscosity data
ethane_viscosity <- subset(ethane_data, 
  (property=="viscosity") & (T>=90) & (T<=675), select=c(T, value)
)
c2h6$dsigma_dt <- 0
ethane_viscosity$value <- 1E-6*ethane_viscosity$value
c2h6$fit_viscosity_data(ethane_viscosity)
print(c2h6$sigma)
print(c2h6$epsk)

# estimate LJ-coefficients from second virial coefficient 
ethane_B <- subset(ethane_data, (property=="BQFH") & (T>= 220) & (T<=623))
ethane_B$value <- 1E-6*ethane_B$value
c2h6$fit_B_data(ethane_B)
print(c2h6$sigma)
print(c2h6$epsk)

## End(Not run)

chapensk documentation built on June 4, 2026, 5:09 p.m.