Learn R Programming

chapensk (version 0.4)

gas: Gas data

Description

Physical properties of some gas species.

Usage

data("gas")

Arguments

Format

A data frame with properties of 43 gases on the following 12 variables.

formula

chemical formula

name

chemical name

CAS

Chemical abstracts registry number

group

point group

M

relative molecular mass

dipole_moment

electric dipole moment in Debye

polarizability

electric polarizability in Ao

IE

ionization energy in eV

Tc

critical temperature in K

pc

critical pressure in bar

rhoc

critical density in mol/l

sigma

distance at which the intermolecular potential between the two particles is zero in Ao

epsk

Well depth \(\varepsilon/k\) of the Lennard-Jones potential in K

DOI

Data source of Lennard-Jones parameters. If not specified otherwise, they are taken from Poling et al. (2004)

Details

Properties of simple gases for the calculation of transport properties. Not all properties are given for all molecules.

References

NIST Chemistry WebBook. NIST Standard Reference Database, vol. 69, 2023. tools:::Rd_expr_doi("10.18434/T4D303").

NIST. Experimental Polarizabilites. in: III RDJ, editor. NIST Computational Chemistry Comparison and Benchmark Database, NIST; 2020. tools:::Rd_expr_doi("10.18434/T47C7Z").

Poling BE, Prausnitz JM, OConnell JP. The Properties of Gases and Liquids. 5 ed. New York: McGraw-Hill; 2004.

Stephan S, Thol M, Vrabec J, Hasse H. Thermophysical Properties of the Lennard-Jones Fluid: Database and Data Assessment. Journal of Chemical Information and Modeling 2019;59:424865. tools:::Rd_expr_doi("10.1021/acs.jcim.9b00620").