| binary_diffusion | R Documentation |
Reference data of binary diffusion coefficients for comparison with calculated diffusion coefficients. Diffusion coefficients were determined using a reversed-flow gas chromatography system.
data("binary_diffusion")
A data frame with 139 observations on the following 6 variables.
doiDOI of data source
bath_gasBath gas: helium, hydrogen, nitrogen
gasDiffusing species: argon, butane, difluoromethane, ethane, fluoromethane, methane, nitrogen, propane, sulfur dioxide, trifluoromethane
TTemperature in K
DDiffusion coefficient in cm2/s
U_DUncertainty of diffusion coefficient in cm2/s
\RemphPlot of experimental diffusion coefficient vs. temperature. (a) diffusion of nitrogen and
argon in helium. (b) diffusion of methane, ethane, propane and butane in helium. (c) diffusion of methane, ethane, propane and butane in nitrogen.
(d) diffusion of sulfur dioxide in hydrogen, helium and nitrogen. The solid lines are calculated using the Lennard-Jones model.
The Lennard-Jones parameters are taken from data set gas.
The diffusion coefficient D as function of pressure in a narrow temperature range close to the reference temperature T_0 is usually expressed as
(Langenberg \Remphet al. 2020)
D = D_0 \left(\frac{p_0}{p}\right)\left(\frac{T}{T_0}\right)^b
For the experimental data, the temperature coefficient b is obtained from the fit. For the calculated diffusion coefficients, the temperature coefficient is
calculated by numerical derivation by
b = \left(\frac{\partial D}{\partial T}\right)_{T_0} \left(\frac{T_0}{D_0}\right).
The diffusion coefficients D_\mathrm{calc} are calculated using Gas-class. The deviation is calculated by
\frac{D_\mathrm{exp} - D_\mathrm{calc}}{D_\mathrm{exp}}.
| Gas | Bath gas | Experimental | Calculated | Deviation | ||
D_0 / [cm2/s] | b | D_0 / [cm2/s] | b |
|||
| nitrogen | helium | 0.605(3) | 1.664(8) | 0.620 | 1.68 | -3% |
| argon | helium | 0.630(2) | 1.665(6) | 0.640 | 1.68 | -2% |
| methane | helium | 0.575(3) | 1.675(7) | 0.597 | 1.68 | -4% |
| ethane | helium | 0.421(5) | 1.68(2) | 0.446 | 1.70 | -6% |
| propane | helium | 0.341(7) | 1.67(2) | 0.361 | 1.70 | -7% |
| n-butane | helium | 0.294(6) | 1.65(2) | 0.368 | 1.74 | -32% |
| methane | nitrogen | 0.201(2) | 1.74(2) | 0.186 | 1.83 | 7% |
| ethane | nitrogen | 0.136(2) | 1.70(2) | 0.123 | 1.87 | 7% |
| propane | nitrogen | 0.106(2) | 1.72(3) | 0.094 | 1.88 | 7% |
| n-butane | nitrogen | 0.090(1) | 1.72(2) | 0.084 | 1.97 | -8% |
| sulfur dioxide | hydrogen | 0.45(2) | 1.77(6) | 0.492 | 1.85 | -14% |
| sulfur dioxide | helium | 0.41(2) | 1.7(1) | 0.490 | 1.71 | -14% |
| sulfur dioxide | nitrogen | 0.112(3) | 1.76(5) | 0.113 | 1.91 | -8% |
The values in brackets indicate the uncertainties (0.95 confidence level) of the fit parameters. With the exception of the diffusion of butane in helium, the calculated diffusion coefficients resemble the measured diffusion coefficients within an error limit of < 15%. For larger non spherical molecules like butane in helium more advanced combining rules need to be applied (Li \Remphet al. 2023).
\RemphPlot of experimental diffusion coefficient vs. temperature of fluoromethane,
difluoromethane and trifluoromethane in nitrogen. The Lennard-Jones parameters are estimated by nonlinear regression using optim
from experimental data.
The experimental data for the diffusion coefficients of fluoromethanes can in turn be used to estimate the Lennard-Jones parameters for the Van der Waals interaction. The values for \Rvarepsilon obtained from diffusion data are smaller than \Rvarepsilon obtained from data of viscosity measurements (Shibasaki-Kitakawa et. al. 1995, Clifford et al. 1979).
| Gas | D_0/ [cm2/s] | b | Viscosity | Diffusion | ||
\sigma / [Ao] | \varepsilon/k / [K] | \sigma / [Ao] | \varepsilon/k / [K] |
|||
| fluoromethane | 0.1576(7) | 1.784(8) | -- | -- | 3.5 | 174 |
| difluoromethane | 0.133(2) | 1.76(2) | 4.9 | 204 | 3.9 | 153 |
| trifluoromethane | 0.123(2) | 1.73(2) | 4.4 | 182 | 4.5 | 63 |
This is due to the fact that the fluoromethanes have a dipole moment. Thus, the well depth of the potential is higher, compared to the only van der Waals interaction. This is why the intermolecular interaction of polar molecules cannot be described in terms of the Lennard-Jones potential.
McGivern WS, Manion JA. Extending reversed-flow chromatographic methods for the measurement of diffusion coefficients to higher temperatures. \RemphJ. Chromatogr. A 2011; 1218:8432-42. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.chroma.2011.09.035")}.
McGivern WS, Manion JA. Hydrocarbon binary diffusion coefficient measurements for use in combustion modeling. \RemphCombustion and Flame 2012;159:3021-6. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.combustflame.2012.04.015")}.
McGivern WS, Manion J. Binary Diffusion Coefficients for Methane and Fluoromethanes in Nitrogen. \RemphJournal of Chemical & Engineering Data 2021; 66:304756. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1021/acs.jced.1c00161")}.
Tsaousoglou DP, Georgiadou E, Gavril D. Determination of Sulfur Dioxide Diffusion Coefficients in Hydrogen, Helium, and Nitrogen by Reversed-Flow Inverse Gas Chromatography. \RemphJ. Chem. Eng. Data 2022; 67:28728. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1021/acs.jced.2c00223")}.
Clifford AA, Gray P, Scott AC. Viscosities of CFCl3, CF3Cl, CHFCl2, CHF2Cl and CHF3 from 373 to 570 K. \RemphJ. Chem. Soc., Faraday Trans. 1, 1979;75:1752. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1039/F19797501752")}
Langenberg S, Carstens T, Hupperich D, Schweighoefer S, Schurath U. Technical note: Determination of binary gas-phase diffusion coefficients of unstable and adsorbing atmospheric trace gases at low temperature arrested flow and twin tube method. \RemphAtmospheric Chemistry and Physics 2020;20:366982. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.5194/acp-20-3669-2020")}.
Li Y, Gui Y, You X. On the binary diffusion coefficients of n-alkanes in He/N2. \RemphCombustion and Flame 2023;257:112795. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.combustflame.2023.112795")}.
Shibasaki-Kitakawa N, Takahashi M, Yokoyama C, Takahashi S. Gas Viscosity of Difluoromethane from 298.15 to 423.15 K and up to 10 MPa \RemphJ. Chem. Eng. Data 1995; 40:900-902 \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1021/je00020a036")}
# binary diffusion data of nitrogen in bath gas helium
nitrogen_in_helium <- subset(binary_diffusion,(gas=="nitrogen" & bath_gas=="helium"))
print(nitrogen_in_helium)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.