| chapensk-package | R Documentation |
Calculation of gas transport properties (viscosity, diffusion, thermal conductivity) using Chapman-Enskok theory (Chapman 1918, <doi:10.1098/rsta.1918.0005>) and of the second virial coefficient (Vargas et al. 2001, <doi:10.1016/s0378-4371(00)00362-9>) using the Lennard-Jones (12-6) potential. Up to the third order correction is taken into account for viscosity and thermal conductivity. It is also possible to calculate the binary diffusion coefficients of polar and non-polar gases in non-polar bath gases (Brown et al. 2011, <doi:10.1016/j.pecs.2010.12.001>). 16 collision integrals are calculated with four digit accuracy over the reduced temperature range [0.3, 400] using an interpolation function of Kim and Monroe (2014, <doi:10.1016/j.jcp.2014.05.018>).
Transport properties, such as viscosity, diffusion and thermal conductivity, play a crucial role in the modeling of combustion processes and chemical reactions. They depend on the intermolecular potential. In practice it is not necessary to have a detailed calculation of the intermolecular potential for the calculation of transport properties.
The interaction between spherical gas particles without a dipole moment can be described by the Lennard-Jones potential. It is given by the following equation:
U(r) = 4\varepsilon\left[\left(\frac{\sigma}{r}\right)^{12} - \left(\frac{\sigma}{r}\right)^6\right]
where r is the distance between two interacting particles, \Rvarepsilon is the depth of the potential well and \Rsigma is the distance at which the
particle-particle potential energy U is zero. The theory of van der Waals interaction gives the exponent 6 for the attractive term (London, 1937).
The 12 exponent in the repulsive term is largely a matter of computational practicality, though it does represent the general nature of Pauli repulsion.
The Lennard-Jones potential only can be used for non-polar molecules, but sometimes is also used for polar molecules. However, for the latter the Stockmayer (12-6-3) potential is more appropriate (Mourits and Rummens, 1977).
For monoatomic gases \Rsigma and \Rvarepsilon are independent of temperature. However, for non-monoatomic gases, averaging over different orientations and vibrational states gives temperature dependent parameters \Rsigma and \Rvarepsilon (Zarkova and Hohm, 2002). The temperature dependency is simplified in this package as follows by a linear temperature coefficient \Rzeta:
\sigma(T) = \sigma + \zeta T
\varepsilon(T) = \varepsilon\left(\frac{\sigma}{\sigma + \zeta T}\right)^6
The Chapman-Enskog theory is a theoretical framework used to describe the transport properties of gases, such as viscosity, thermal conductivity, and diffusion coefficients. The theory is based on the idea that the properties of a gas can be related to the collisional interactions between individual gas molecules (Chapman 1918).
Collision integrals are mathematical expressions that arise in the Chapman-Enskog theory. They quantify the effects of molecular collisions on the transport properties of a gas.
An object-oriented framework has been developed to calculate transport properties from potential parameters and vice versa. A class Gas has been defined for the calculation of the properties of gas. To facilitate calculations, a data set gas is provided for the properties of some common gases. The CollisionIntegral class is used to calculate collision integrals using an interpolation function and fit parameters from data set coefficients_collisionintegral.
Lennard-Jones parameters of non-polar molecules can be estimated using high quality of viscosity and second virial coefficients. This is demonstrated for ethane, see data set ethane_data. For polar molecules Lennard-Jones parameters for the van der Waals interaction part can be estimated from measurements of binary diffusion coefficients, see data set binary_diffusion.
| Symbol | Description | Unit | Global variable |
b | temperature coefficient of diffusion | - |
|
B | second virial coefficient | m3 |
|
D | diffusion coefficient | m2/2 |
|
k | Boltzmann constant | J/K | pkg.env$k |
m | molecular mass | kg |
|
M | relative molecular mass | - |
|
N_a | Avogadro constant | 1/mol | pkg.env$Na |
n | mole | mol |
|
p | pressure | Pa |
|
p_0 | standard pressure 101325 Pa | Pa | pkg.env$p0 |
p_c | critical pressure | Pa |
|
R | gas constant | J/(K.mol) | pkg.env$R |
T | temperature | K |
|
T_0 | standard temperature 273.15 K | K | pkg.env$T0 |
T_c | critical temperature | K |
|
V | gas volume | m3 |
|
\alpha | polarizability | Ao3 |
|
\bar{\alpha} | reduced polarizability | - |
|
\eta | dynamic viscosity | Pa.s |
|
\epsilon | permittivity of vacuum | F/m | pkg.env$eps0 |
\varepsilon | depth of potential well | J |
|
\kappa | thermal conductivity | W/(m.K) |
|
\mu | dipole moment | D |
|
\bar{\mu} | reduced dipole moment | - |
|
\Omega | reduced collision integral | - |
|
\rho | gas density | kg/m3 |
|
\rho_c | critical density | mol/l |
|
\Theta | reduced temperature | - |
|
\sigma | distance at which the potential energy is zero | Ao |
|
\xi | scaling parameter | - |
|
\zeta | temperature coefficient of \Rsigma | Ao/K
|
Physical units are displayed in UCUM notation.
Stefan Langenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-5817-5469>)
Maintainer: Stefan Langenberg <langenberg@uni-bonn.de>
Brown NJ, Bastien LAJ, Price PN. Transport properties for combustion modeling. \RemphProgress in Energy and Combustion Science 2011;37:565-82. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.pecs.2010.12.001")}.
Chapman SV. On the kinetic theory of a gas. Part II. A composite monatomic gas: diffusion, viscosity, and thermal conduction. \RemphPhilosophical Transactions of the Royal Society of London. Series A 1918;217:11597. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1098/rsta.1918.0005")}.
London F. The general theory of molecular forces. \RemphTransactions of the Faraday Society 1937;33:8b. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1039/tf937330008b")}.
Mourits FM, Rummens FHA. A critical evaluation of Lennard-Jones and Stockmayer potential parameters and of some correlation methods. \RemphCan. J. Chem. 1977;55:300720. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1139/v77-418")}.
Zarkova L, Hohm U. pVT-Second Virial Coefficients B(T), Viscosity \Reta and Self-Diffusion \rho D(T) of the Gases: BF3, CF4,
SiF4, CCl4, SiCl4, SF6, MoF6, WF6, UF6, C(CH3)4, and Si(CH3)4 Determined by Means of an Isotropic Temperature-Dependent Potential.
\RemphJournal of Physical and Chemical Reference Data 2002;31:183216. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1063/1.1433462")}.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.