tools:::Rd_package_description("chapensk")
Transport properties, such as viscosity, diffusion and thermal conductivity, play a crucial role in the modeling of combustion processes and chemical reactions. They depend on the intermolecular potential. In practice it is not necessary to have a detailed calculation of the intermolecular potential for the calculation of transport properties.
The interaction between spherical gas particles without a dipole moment can be described by the Lennard-Jones potential.
The Lennard-Jones potential only can be used for non-polar molecules, but sometimes is also used for polar molecules. However, for the latter the Stockmayer (12-6-3) potential is more appropriate (Mourits and Rummens, 1977).
The Chapman-Enskog theory is a theoretical framework used to describe the transport properties of gases, such as viscosity, thermal conductivity, and diffusion coefficients. The theory is based on the idea that the properties of a gas can be related to the collisional interactions between individual gas molecules (Chapman and Larmor 1918).
Collision integrals are mathematical expressions that arise in the Chapman-Enskog theory. They quantify the effects of molecular collisions on the transport properties of a gas.
An object-oriented framework has been developed to calculate transport properties from potential parameters and vice versa. A class Gas has been defined for the calculation of the properties of gas. To facilitate calculations, a gas data set is provided for the properties of some common gases. The CollisionIntegral class is used to calculate collision integrals using an interpolation function and fit parameters from dataset coefficients_collisionintegral.
Lennard-Jones parameters of non-polar molecules can be estimated using high quality of viscosity and second virial coefficients. This is demonstrated for ethane, see data set ethane_data. For polar molecules Lennard-Jones parameters for the Van der Walls interaction part can be estimated from measurements of binary diffusion coefficients, see data set binary_diffusion.
| Symbol | Description | Unit | Global variable |
| \(b\) | temperature coefficient of diffusion | - | \(B\) |
| second virial coefficient | m3 | \(D\) | diffusion coefficient |
m2/2 | \(k\) | Boltzmann constant | J/K |
pkg.env$k | \(m\) | molecular mass | kg |
| \(M\) | relative molecular mass | - | \(N_a\) |
| Avogadro constant | 1/mol | pkg.env$Na | \(n\) |
| mole | mol | \(p\) | pressure |
Pa | \(p_0\) | standard pressure 101325 Pa | Pa |
pkg.env$p0 | \(p_c\) | critical pressure | Pa |
| \(R\) | gas constant | J/(K.mol) | pkh.env$R |
| \(T\) | temperature | K | \(T_0\) |
| standard temperature 273.15 K | K | pkg.env$T0 | \(T_c\) |
| critical temperature | K | \(V\) | gas volume |
m3 | \(\alpha\) | polarizability | Ao3 |
| \(\bar{\alpha}\) | reduced polarizability | - | \(\eta\) |
| dynamic viscosity | Pa.s | \(\epsilon\) | permittivity of vacuum |
F/m | pkg.env$eps0 | \(\varepsilon\) | depth of potential well |
J | \(\kappa\) | thermal conductivity | W/(m.K) |
| \(\mu\) | dipole moment | D | \(\bar{\mu}\) |
| reduced dipole moment | - | \(\Omega\) | reduced collision integral |
- | \(\rho\) | gas density | kg/m3 |
| \(\rho_c\) | critical density | mol/l | \(\Theta\) |
| reduced temperature | - | \(\sigma\) | distance at which the potential energy is zero |
Ao | \(\xi\) | scaling parameter | - |
Physical units are displayed in UCUM notation.
tools:::Rd_package_author("chapensk")
Maintainer: tools:::Rd_package_maintainer("chapensk")
Brown NJ, Bastien LAJ, Price PN. Transport properties for combustion modeling. Progress in Energy and Combustion Science 2011;37:565-82. tools:::Rd_expr_doi("10.1016/j.pecs.2010.12.001").
Chapman S, Larmor J. V. On the kinetic theory of a gas. Part II. A composite monatomic gas: diffusion, viscosity, and thermal conduction. Philosophical Transactions of the Royal Society of London. Series A 1918;217:11597. tools:::Rd_expr_doi("10.1098/rsta.1918.0005").
London F. The general theory of molecular forces. Transactions of the Faraday Society 1937;33:8b. tools:::Rd_expr_doi("10.1039/tf937330008b").
Mourits FM, Rummens FHA. A critical evaluation of Lennard-Jones and Stockmayer potential parameters and of some correlation methods. Can. J. Chem. 1977;55:300720. tools:::Rd_expr_doi("10.1139/v77-418").
Zarkova L, Hohm U. pVT-Second Virial Coefficients \(B(T)\), Viscosity η and Self-Diffusion \(\rho D(T)\) of the Gases: BF3, CF4, SiF4, CCl4, SiCl4, SF6, MoF6, WF6, UF6, C(CH3)4, and Si(CH3)4 Determined by Means of an Isotropic Temperature-Dependent Potential. Journal of Physical and Chemical Reference Data 2002;31:183216. tools:::Rd_expr_doi("10.1063/1.1433462").