Physical properties of some gas species.
data("gas")A data frame with properties of 43 gases on the following 12 variables.
formulachemical formula
namechemical name
CASChemical abstracts registry number
group
M
dipole_momentelectric dipole moment in Debye
polarizabilityelectric polarizability in Ao
IEionization energy in eV
Tccritical temperature in K
pccritical pressure in bar
rhoccritical density in mol/l
sigmadistance at which the intermolecular potential between the two particles is zero in Ao
epskWell depth \(\varepsilon/k\) of the Lennard-Jones potential in K
DOIData source of Lennard-Jones parameters. If not specified otherwise, they are taken from Poling et al. (2004)
Properties of simple gases for the calculation of transport properties. Not all properties are given for all molecules.
NIST Chemistry WebBook. NIST Standard Reference Database, vol. 69, 2023. tools:::Rd_expr_doi("10.18434/T4D303").
NIST. Experimental Polarizabilites. in: III RDJ, editor. NIST Computational Chemistry Comparison and Benchmark Database, NIST; 2020. tools:::Rd_expr_doi("10.18434/T47C7Z").
Poling BE, Prausnitz JM, OConnell JP. The Properties of Gases and Liquids. 5 ed. New York: McGraw-Hill; 2004.
Stephan S, Thol M, Vrabec J, Hasse H. Thermophysical Properties of the Lennard-Jones Fluid: Database and Data Assessment. Journal of Chemical Information and Modeling 2019;59:424865. tools:::Rd_expr_doi("10.1021/acs.jcim.9b00620").